pub enum ServiceBusTokenCredential {
SharedAccessCredential(SharedAccessCredential),
Other(Arc<dyn TokenCredential>),
}Expand description
Token-based credential for Service Bus.
This supports SharedAccessCredential and other credential types that
implement TokenCredential (eg. azure_identity::DefaultAzureCredential).
Example
use azure_identity::DefaultAzureCredential;
use azservicebus::authorization::ServiceBusTokenCredential;
let default_credential = DefaultAzureCredential::new().unwrap();
let credential = ServiceBusTokenCredential::from(default_credential);Variants
Shared Access Signature credential.
FIXME: This is a temporary workaround until specialization is stablized.
Other(Arc<dyn TokenCredential>)
Other credential types.
TODO: Is the use of trait object here justified?
Implementations
Sourceimpl ServiceBusTokenCredential
impl ServiceBusTokenCredential
Sourcepub fn new(source: Arc<dyn TokenCredential>) -> Self
pub fn new(source: Arc<dyn TokenCredential>) -> Self
Creates a new ServiceBusTokenCredential from the given credential. This is an alias for
From::from.
Indicates whether the credential is based on an Service Bus shared access policy.